# client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `truefoundry.ml._autogen.client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.1.0
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic
* aenum

## Getting Started

In your own code, to use this library to connect and interact with client,
you can run the following:

```python

import time
import truefoundry.ml._autogen.client
from truefoundry.ml._autogen.client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = truefoundry.ml._autogen.client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with truefoundry.ml._autogen.client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = truefoundry.ml._autogen.client.AuthApi(api_client)
    host_name = 'host_name_example' # str |

    try:
        # Get Tenant Id
        api_response = api_instance.get_tenant_id_get(host_name)
        print("The response of AuthApi->get_tenant_id_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->get_tenant_id_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**get_tenant_id_get**](truefoundry/ml/_autogen/client/docs/AuthApi.md#get_tenant_id_get) | **GET** /api/2.0/mlflow/tenant-id | Get Tenant Id
*DeprecatedApi* | [**get_run_by_name_get**](truefoundry/ml/_autogen/client/docs/DeprecatedApi.md#get_run_by_name_get) | **GET** /api/2.0mlflow/runs/get-by-name | Get Run By Name
*DeprecatedApi* | [**get_search_runs_get**](truefoundry/ml/_autogen/client/docs/DeprecatedApi.md#get_search_runs_get) | **GET** /api/2.0/preview/mlflow/runs/search | Get Search Runs
*DeprecatedApi* | [**get_signed_urls_for_dataset_write_deprecated_get**](truefoundry/ml/_autogen/client/docs/DeprecatedApi.md#get_signed_urls_for_dataset_write_deprecated_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/datasets/get-signed-urls-for-write | Get Signed Urls For Dataset Write Deprecated
*ExperimentsApi* | [**create_experiment_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#create_experiment_post) | **POST** /api/2.0/mlflow/experiments/create | Create Experiment
*ExperimentsApi* | [**delete_experiment_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#delete_experiment_post) | **POST** /api/2.0/mlflow/experiments/delete | Delete Experiment
*ExperimentsApi* | [**get_experiment_by_name_get**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#get_experiment_by_name_get) | **GET** /api/2.0/mlflow/experiments/get-by-name | Get Experiment By Name
*ExperimentsApi* | [**get_experiment_get**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#get_experiment_get) | **GET** /api/2.0/mlflow/experiments/get | Get Experiment
*ExperimentsApi* | [**hard_delete_experiment_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#hard_delete_experiment_post) | **POST** /api/2.0/mlflow/experiments/hard-delete | Hard Delete Experiment
*ExperimentsApi* | [**list_experiment_columns_get**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#list_experiment_columns_get) | **GET** /api/2.0/mlflow/experiments/columns | List Experiment Columns
*ExperimentsApi* | [**list_experiments_get**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#list_experiments_get) | **GET** /api/2.0/mlflow/experiments/list | List Experiments
*ExperimentsApi* | [**restore_experiment_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#restore_experiment_post) | **POST** /api/2.0/mlflow/experiments/restore | Restore Experiment
*ExperimentsApi* | [**set_experiment_tag_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#set_experiment_tag_post) | **POST** /api/2.0/mlflow/experiments/set-experiment-tag | Set Experiment Tag
*ExperimentsApi* | [**update_experiment_post**](truefoundry/ml/_autogen/client/docs/ExperimentsApi.md#update_experiment_post) | **POST** /api/2.0/mlflow/experiments/update | Update Experiment
*GenerateCodeSnippetApi* | [**generate_py_development_config_post**](truefoundry/ml/_autogen/client/docs/GenerateCodeSnippetApi.md#generate_py_development_config_post) | **POST** /api/2.0/mlflow/generate-code-snippet/application | Generate Py Development Config
*GenerateCodeSnippetApi* | [**trigger_job_run_post**](truefoundry/ml/_autogen/client/docs/GenerateCodeSnippetApi.md#trigger_job_run_post) | **POST** /api/2.0/mlflow/generate-code-snippet/trigger-job-run | Trigger Job Run
*GenerateCodeSnippetApi* | [**trigger_workflow_task_config_post**](truefoundry/ml/_autogen/client/docs/GenerateCodeSnippetApi.md#trigger_workflow_task_config_post) | **POST** /api/2.0/mlflow/generate-code-snippet/workflow-task-config | Trigger Workflow Task Config
*HealthApi* | [**health_get**](truefoundry/ml/_autogen/client/docs/HealthApi.md#health_get) | **GET** /health | Health
*HealthApi* | [**serve_get**](truefoundry/ml/_autogen/client/docs/HealthApi.md#serve_get) | **GET** / | Serve
*MetricsApi* | [**get_metric_history_get**](truefoundry/ml/_autogen/client/docs/MetricsApi.md#get_metric_history_get) | **GET** /api/2.0/mlflow/metrics/get-history | Get Metric History
*MetricsApi* | [**list_metric_history_post**](truefoundry/ml/_autogen/client/docs/MetricsApi.md#list_metric_history_post) | **POST** /api/2.0/mlflow/metrics/list-history | List Metric History
*MlfoundryArtifactsApi* | [**apply_manifest_put**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#apply_manifest_put) | **PUT** /api/2.0/mlflow/mlfoundry-artifacts/apply | Apply Manifest
*MlfoundryArtifactsApi* | [**authorize_user_for_model_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#authorize_user_for_model_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/models/authorize | Authorize User For Model
*MlfoundryArtifactsApi* | [**authorize_user_for_model_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#authorize_user_for_model_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/authorize | Authorize User For Model Version
*MlfoundryArtifactsApi* | [**create_artifact_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_artifact_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifacts/create | Create Artifact
*MlfoundryArtifactsApi* | [**create_artifact_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_artifact_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/create | Create Artifact Version
*MlfoundryArtifactsApi* | [**create_dataset_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_dataset_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/create | Create Dataset
*MlfoundryArtifactsApi* | [**create_model_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_model_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/create | Create Model Version
*MlfoundryArtifactsApi* | [**create_multi_part_upload_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_multi_part_upload_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/multi-part-upload/create | Create Multi Part Upload
*MlfoundryArtifactsApi* | [**create_multipart_upload_for_dataset_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#create_multipart_upload_for_dataset_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/multi-part-upload/create | Create Multipart Upload For Dataset
*MlfoundryArtifactsApi* | [**delete_artifact_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#delete_artifact_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact/delete | Delete Artifact
*MlfoundryArtifactsApi* | [**delete_artifact_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#delete_artifact_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/delete | Delete Artifact Version
*MlfoundryArtifactsApi* | [**delete_dataset_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#delete_dataset_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/delete | Delete Dataset
*MlfoundryArtifactsApi* | [**delete_files_for_dataset_delete**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#delete_files_for_dataset_delete) | **DELETE** /api/2.0/mlflow/mlfoundry-artifacts/datasets/files/ | Delete Files For Dataset
*MlfoundryArtifactsApi* | [**delete_model_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#delete_model_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/delete | Delete Model Version
*MlfoundryArtifactsApi* | [**export_deployment_files_by_fqn_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#export_deployment_files_by_fqn_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/export-deployment-files-by-fqn | Export Deployment Files By Fqn
*MlfoundryArtifactsApi* | [**finalize_artifact_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#finalize_artifact_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/finalize | Finalize Artifact Version
*MlfoundryArtifactsApi* | [**get_artifact_by_fqn_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_artifact_by_fqn_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifacts/get-by-fqn | Get Artifact By Fqn
*MlfoundryArtifactsApi* | [**get_artifact_by_id_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_artifact_by_id_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifacts/get | Get Artifact By Id
*MlfoundryArtifactsApi* | [**get_artifact_version_by_fqn_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_artifact_version_by_fqn_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/get-by-fqn | Get Artifact Version By Fqn
*MlfoundryArtifactsApi* | [**get_artifact_version_by_id_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_artifact_version_by_id_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/get | Get Artifact Version By Id
*MlfoundryArtifactsApi* | [**get_artifact_version_by_name_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_artifact_version_by_name_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/get-by-name | Get Artifact Version By Name
*MlfoundryArtifactsApi* | [**get_dataset_by_fqn_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_dataset_by_fqn_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/datasets/get-by-fqn | Get Dataset By Fqn
*MlfoundryArtifactsApi* | [**get_dataset_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_dataset_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/datasets/get | Get Dataset
*MlfoundryArtifactsApi* | [**get_model_by_fqn_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_by_fqn_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/models/get-by-fqn | Get Model By Fqn
*MlfoundryArtifactsApi* | [**get_model_by_name_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_by_name_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/models/get-by-name | Get Model By Name
*MlfoundryArtifactsApi* | [**get_model_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/models/get | Get Model
*MlfoundryArtifactsApi* | [**get_model_version_by_fqn_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_version_by_fqn_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/get-by-fqn | Get Model Version By Fqn
*MlfoundryArtifactsApi* | [**get_model_version_by_name_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_version_by_name_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/get-by-name | Get Model Version By Name
*MlfoundryArtifactsApi* | [**get_model_version_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_model_version_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/get | Get Model Version
*MlfoundryArtifactsApi* | [**get_signed_urls_dataset_read_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_signed_urls_dataset_read_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/get-signed-urls-for-read | Get Signed Urls Dataset Read
*MlfoundryArtifactsApi* | [**get_signed_urls_for_dataset_write_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_signed_urls_for_dataset_write_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/get-signed-urls-for-write | Get Signed Urls For Dataset Write
*MlfoundryArtifactsApi* | [**get_signed_urls_for_read_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_signed_urls_for_read_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/get-signed-urls-for-read | Get Signed Urls For Read
*MlfoundryArtifactsApi* | [**get_signed_urls_for_write_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_signed_urls_for_write_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/get-signed-urls-for-write | Get Signed Urls For Write
*MlfoundryArtifactsApi* | [**get_version_aliases_for_artifact_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#get_version_aliases_for_artifact_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/artifacts/get-version-aliases | Get Version Aliases For Artifact
*MlfoundryArtifactsApi* | [**list_artifact_versions_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_artifact_versions_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/list | List Artifact Versions
*MlfoundryArtifactsApi* | [**list_artifacts_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_artifacts_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifacts/list | List Artifacts
*MlfoundryArtifactsApi* | [**list_datasets_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_datasets_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/list | List Datasets
*MlfoundryArtifactsApi* | [**list_files_for_artifact_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_files_for_artifact_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/files/list | List Files For Artifact Version
*MlfoundryArtifactsApi* | [**list_files_for_dataset_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_files_for_dataset_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/files/list | List Files For Dataset
*MlfoundryArtifactsApi* | [**list_model_versions_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_model_versions_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/list | List Model Versions
*MlfoundryArtifactsApi* | [**list_models_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#list_models_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/models/list | List Models
*MlfoundryArtifactsApi* | [**notify_failure_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#notify_failure_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/notify-failure | Notify Failure
*MlfoundryArtifactsApi* | [**resolve_agent_get**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#resolve_agent_get) | **GET** /api/2.0/mlflow/mlfoundry-artifacts/agent/resolve | Resolve Agent
*MlfoundryArtifactsApi* | [**update_artifact_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#update_artifact_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/update | Update Artifact Version
*MlfoundryArtifactsApi* | [**update_dataset_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#update_dataset_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/datasets/update | Update Dataset
*MlfoundryArtifactsApi* | [**update_model_version_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#update_model_version_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/model-versions/update | Update Model Version
*MlfoundryArtifactsApi* | [**validate_external_storage_root_path_post**](truefoundry/ml/_autogen/client/docs/MlfoundryArtifactsApi.md#validate_external_storage_root_path_post) | **POST** /api/2.0/mlflow/mlfoundry-artifacts/artifact-versions/validate-storage-root | Validate External Storage Root Path
*RunArtifactsApi* | [**list_run_artifacts_get**](truefoundry/ml/_autogen/client/docs/RunArtifactsApi.md#list_run_artifacts_get) | **GET** /api/2.0/mlflow/artifacts/list | List Run Artifacts
*RunsApi* | [**create_run_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#create_run_post) | **POST** /api/2.0/mlflow/runs/create | Create Run
*RunsApi* | [**delete_run_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#delete_run_post) | **POST** /api/2.0/mlflow/runs/delete | Delete Run
*RunsApi* | [**delete_tag_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#delete_tag_post) | **POST** /api/2.0/mlflow/runs/delete-tag | Delete Tag
*RunsApi* | [**get_run_by_fqn_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#get_run_by_fqn_get) | **GET** /api/2.0/mlflow/runs/get-by-fqn | Get Run By Fqn
*RunsApi* | [**get_run_by_name_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#get_run_by_name_get) | **GET** /api/2.0/mlflow/runs/get-by-name | Get Run By Name
*RunsApi* | [**get_run_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#get_run_get) | **GET** /api/2.0/mlflow/runs/get | Get Run
*RunsApi* | [**hard_delete_run_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#hard_delete_run_post) | **POST** /api/2.0/mlflow/runs/hard-delete | Hard Delete Run
*RunsApi* | [**latest_run_log_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#latest_run_log_get) | **GET** /api/2.0/mlflow/runs/run-logs/latest-run-log | Latest Run Log
*RunsApi* | [**list_latest_run_logs_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#list_latest_run_logs_get) | **GET** /api/2.0/mlflow/runs/run-logs/list-latest | List Latest Run Logs
*RunsApi* | [**list_run_logs_get**](truefoundry/ml/_autogen/client/docs/RunsApi.md#list_run_logs_get) | **GET** /api/2.0/mlflow/runs/run-logs/list | List Run Logs
*RunsApi* | [**log_metric_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#log_metric_post) | **POST** /api/2.0/mlflow/runs/log-metric | Log Metric
*RunsApi* | [**log_parameter_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#log_parameter_post) | **POST** /api/2.0/mlflow/runs/log-parameter | Log Parameter
*RunsApi* | [**log_run_batch_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#log_run_batch_post) | **POST** /api/2.0/mlflow/runs/log-batch | Log Run Batch
*RunsApi* | [**restore_run_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#restore_run_post) | **POST** /api/2.0/mlflow/runs/restore | Restore Run
*RunsApi* | [**run_logs_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#run_logs_post) | **POST** /api/2.0/mlflow/runs/run-logs | Run Logs
*RunsApi* | [**search_runs_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#search_runs_post) | **POST** /api/2.0/mlflow/runs/search | Search Runs
*RunsApi* | [**set_tag_request_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#set_tag_request_post) | **POST** /api/2.0/mlflow/runs/set-tag | Set Tag Request
*RunsApi* | [**update_run_post**](truefoundry/ml/_autogen/client/docs/RunsApi.md#update_run_post) | **POST** /api/2.0/mlflow/runs/update | Update Run


## Documentation For Models

 - [AgentApp](truefoundry/ml/_autogen/client/docs/AgentApp.md)
 - [AgentManifest](truefoundry/ml/_autogen/client/docs/AgentManifest.md)
 - [AgentOpenAPIToolManifest](truefoundry/ml/_autogen/client/docs/AgentOpenAPIToolManifest.md)
 - [AgentOpenAPIToolWithFQN](truefoundry/ml/_autogen/client/docs/AgentOpenAPIToolWithFQN.md)
 - [AgentWithFQN](truefoundry/ml/_autogen/client/docs/AgentWithFQN.md)
 - [ApplyRequestDto](truefoundry/ml/_autogen/client/docs/ApplyRequestDto.md)
 - [ApplyResponseDto](truefoundry/ml/_autogen/client/docs/ApplyResponseDto.md)
 - [ArtifactDto](truefoundry/ml/_autogen/client/docs/ArtifactDto.md)
 - [ArtifactManifest](truefoundry/ml/_autogen/client/docs/ArtifactManifest.md)
 - [ArtifactPath](truefoundry/ml/_autogen/client/docs/ArtifactPath.md)
 - [ArtifactResponseDto](truefoundry/ml/_autogen/client/docs/ArtifactResponseDto.md)
 - [ArtifactType](truefoundry/ml/_autogen/client/docs/ArtifactType.md)
 - [ArtifactVersionDto](truefoundry/ml/_autogen/client/docs/ArtifactVersionDto.md)
 - [ArtifactVersionResponseDto](truefoundry/ml/_autogen/client/docs/ArtifactVersionResponseDto.md)
 - [ArtifactVersionSerializationFormat](truefoundry/ml/_autogen/client/docs/ArtifactVersionSerializationFormat.md)
 - [ArtifactVersionStatus](truefoundry/ml/_autogen/client/docs/ArtifactVersionStatus.md)
 - [AssistantMessage](truefoundry/ml/_autogen/client/docs/AssistantMessage.md)
 - [AuthorizeUserForModelRequestDto](truefoundry/ml/_autogen/client/docs/AuthorizeUserForModelRequestDto.md)
 - [AuthorizeUserForModelVersionRequestDto](truefoundry/ml/_autogen/client/docs/AuthorizeUserForModelVersionRequestDto.md)
 - [BlobStorageReference](truefoundry/ml/_autogen/client/docs/BlobStorageReference.md)
 - [BodyGetSearchRunsGet](truefoundry/ml/_autogen/client/docs/BodyGetSearchRunsGet.md)
 - [ChatPromptManifest](truefoundry/ml/_autogen/client/docs/ChatPromptManifest.md)
 - [ChatPromptManifestMessagesInner](truefoundry/ml/_autogen/client/docs/ChatPromptManifestMessagesInner.md)
 - [ColumnsDto](truefoundry/ml/_autogen/client/docs/ColumnsDto.md)
 - [Command](truefoundry/ml/_autogen/client/docs/Command.md)
 - [Content](truefoundry/ml/_autogen/client/docs/Content.md)
 - [Content1](truefoundry/ml/_autogen/client/docs/Content1.md)
 - [Content2](truefoundry/ml/_autogen/client/docs/Content2.md)
 - [Content2AnyOfInner](truefoundry/ml/_autogen/client/docs/Content2AnyOfInner.md)
 - [CreateArtifactRequestDto](truefoundry/ml/_autogen/client/docs/CreateArtifactRequestDto.md)
 - [CreateArtifactResponseDto](truefoundry/ml/_autogen/client/docs/CreateArtifactResponseDto.md)
 - [CreateArtifactVersionRequestDto](truefoundry/ml/_autogen/client/docs/CreateArtifactVersionRequestDto.md)
 - [CreateArtifactVersionResponseDto](truefoundry/ml/_autogen/client/docs/CreateArtifactVersionResponseDto.md)
 - [CreateDatasetRequestDto](truefoundry/ml/_autogen/client/docs/CreateDatasetRequestDto.md)
 - [CreateExperimentRequestDto](truefoundry/ml/_autogen/client/docs/CreateExperimentRequestDto.md)
 - [CreateExperimentResponseDto](truefoundry/ml/_autogen/client/docs/CreateExperimentResponseDto.md)
 - [CreateModelVersionRequestDto](truefoundry/ml/_autogen/client/docs/CreateModelVersionRequestDto.md)
 - [CreateMultiPartUploadForDatasetRequestDto](truefoundry/ml/_autogen/client/docs/CreateMultiPartUploadForDatasetRequestDto.md)
 - [CreateMultiPartUploadForDatasetResponseDto](truefoundry/ml/_autogen/client/docs/CreateMultiPartUploadForDatasetResponseDto.md)
 - [CreateMultiPartUploadRequestDto](truefoundry/ml/_autogen/client/docs/CreateMultiPartUploadRequestDto.md)
 - [CreatePythonDeploymentConfigRequestDto](truefoundry/ml/_autogen/client/docs/CreatePythonDeploymentConfigRequestDto.md)
 - [CreatePythonDeploymentConfigResponseDto](truefoundry/ml/_autogen/client/docs/CreatePythonDeploymentConfigResponseDto.md)
 - [CreateRunRequestDto](truefoundry/ml/_autogen/client/docs/CreateRunRequestDto.md)
 - [CreateRunResponseDto](truefoundry/ml/_autogen/client/docs/CreateRunResponseDto.md)
 - [CreateWorkflowTaskConfigRequestDto](truefoundry/ml/_autogen/client/docs/CreateWorkflowTaskConfigRequestDto.md)
 - [DataDirectoryManifest](truefoundry/ml/_autogen/client/docs/DataDirectoryManifest.md)
 - [DatasetDto](truefoundry/ml/_autogen/client/docs/DatasetDto.md)
 - [DatasetResponseDto](truefoundry/ml/_autogen/client/docs/DatasetResponseDto.md)
 - [DeleteArtifactVersionsRequestDto](truefoundry/ml/_autogen/client/docs/DeleteArtifactVersionsRequestDto.md)
 - [DeleteDatasetRequestDto](truefoundry/ml/_autogen/client/docs/DeleteDatasetRequestDto.md)
 - [DeleteFilesForDatasetRequestDto](truefoundry/ml/_autogen/client/docs/DeleteFilesForDatasetRequestDto.md)
 - [DeleteModelVersionRequestDto](truefoundry/ml/_autogen/client/docs/DeleteModelVersionRequestDto.md)
 - [DeleteRunRequest](truefoundry/ml/_autogen/client/docs/DeleteRunRequest.md)
 - [DeleteTagRequestDto](truefoundry/ml/_autogen/client/docs/DeleteTagRequestDto.md)
 - [ExperimentDto](truefoundry/ml/_autogen/client/docs/ExperimentDto.md)
 - [ExperimentIdRequestDto](truefoundry/ml/_autogen/client/docs/ExperimentIdRequestDto.md)
 - [ExperimentResponseDto](truefoundry/ml/_autogen/client/docs/ExperimentResponseDto.md)
 - [ExperimentTagDto](truefoundry/ml/_autogen/client/docs/ExperimentTagDto.md)
 - [ExportDeploymentFilesRequestDto](truefoundry/ml/_autogen/client/docs/ExportDeploymentFilesRequestDto.md)
 - [ExternalBlobStorageSource](truefoundry/ml/_autogen/client/docs/ExternalBlobStorageSource.md)
 - [FastAIFramework](truefoundry/ml/_autogen/client/docs/FastAIFramework.md)
 - [FileInfoDto](truefoundry/ml/_autogen/client/docs/FileInfoDto.md)
 - [FinalizeArtifactVersionRequestDto](truefoundry/ml/_autogen/client/docs/FinalizeArtifactVersionRequestDto.md)
 - [Framework](truefoundry/ml/_autogen/client/docs/Framework.md)
 - [GetArtifactVersionAliasesResponseDto](truefoundry/ml/_autogen/client/docs/GetArtifactVersionAliasesResponseDto.md)
 - [GetExperimentResponseDto](truefoundry/ml/_autogen/client/docs/GetExperimentResponseDto.md)
 - [GetLatestRunLogResponseDto](truefoundry/ml/_autogen/client/docs/GetLatestRunLogResponseDto.md)
 - [GetMetricHistoryResponse](truefoundry/ml/_autogen/client/docs/GetMetricHistoryResponse.md)
 - [GetSignedURLForDatasetWriteRequestDto](truefoundry/ml/_autogen/client/docs/GetSignedURLForDatasetWriteRequestDto.md)
 - [GetSignedURLsForArtifactVersionReadRequestDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForArtifactVersionReadRequestDto.md)
 - [GetSignedURLsForArtifactVersionReadResponseDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForArtifactVersionReadResponseDto.md)
 - [GetSignedURLsForArtifactVersionWriteRequestDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForArtifactVersionWriteRequestDto.md)
 - [GetSignedURLsForArtifactVersionWriteResponseDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForArtifactVersionWriteResponseDto.md)
 - [GetSignedURLsForDatasetReadRequestDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForDatasetReadRequestDto.md)
 - [GetSignedURLsForDatasetReadResponseDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForDatasetReadResponseDto.md)
 - [GetSignedURLsForDatasetWriteResponseDto](truefoundry/ml/_autogen/client/docs/GetSignedURLsForDatasetWriteResponseDto.md)
 - [GetTenantIdResponseDto](truefoundry/ml/_autogen/client/docs/GetTenantIdResponseDto.md)
 - [GluonFramework](truefoundry/ml/_autogen/client/docs/GluonFramework.md)
 - [H2OFramework](truefoundry/ml/_autogen/client/docs/H2OFramework.md)
 - [HTTPValidationError](truefoundry/ml/_autogen/client/docs/HTTPValidationError.md)
 - [ImageContentPart](truefoundry/ml/_autogen/client/docs/ImageContentPart.md)
 - [ImageUrl](truefoundry/ml/_autogen/client/docs/ImageUrl.md)
 - [InferMethodName](truefoundry/ml/_autogen/client/docs/InferMethodName.md)
 - [KerasFramework](truefoundry/ml/_autogen/client/docs/KerasFramework.md)
 - [LatestRunLogDto](truefoundry/ml/_autogen/client/docs/LatestRunLogDto.md)
 - [LibraryName](truefoundry/ml/_autogen/client/docs/LibraryName.md)
 - [LightGBMFramework](truefoundry/ml/_autogen/client/docs/LightGBMFramework.md)
 - [ListArtifactVersionsRequestDto](truefoundry/ml/_autogen/client/docs/ListArtifactVersionsRequestDto.md)
 - [ListArtifactVersionsResponseDto](truefoundry/ml/_autogen/client/docs/ListArtifactVersionsResponseDto.md)
 - [ListArtifactsRequestDto](truefoundry/ml/_autogen/client/docs/ListArtifactsRequestDto.md)
 - [ListArtifactsResponseDto](truefoundry/ml/_autogen/client/docs/ListArtifactsResponseDto.md)
 - [ListColumsResponseDto](truefoundry/ml/_autogen/client/docs/ListColumsResponseDto.md)
 - [ListDatasetsRequestDto](truefoundry/ml/_autogen/client/docs/ListDatasetsRequestDto.md)
 - [ListDatasetsResponseDto](truefoundry/ml/_autogen/client/docs/ListDatasetsResponseDto.md)
 - [ListExperimentsResponseDto](truefoundry/ml/_autogen/client/docs/ListExperimentsResponseDto.md)
 - [ListFilesForArtifactVersionRequestDto](truefoundry/ml/_autogen/client/docs/ListFilesForArtifactVersionRequestDto.md)
 - [ListFilesForArtifactVersionsResponseDto](truefoundry/ml/_autogen/client/docs/ListFilesForArtifactVersionsResponseDto.md)
 - [ListFilesForDatasetRequestDto](truefoundry/ml/_autogen/client/docs/ListFilesForDatasetRequestDto.md)
 - [ListFilesForDatasetResponseDto](truefoundry/ml/_autogen/client/docs/ListFilesForDatasetResponseDto.md)
 - [ListLatestRunLogsResponseDto](truefoundry/ml/_autogen/client/docs/ListLatestRunLogsResponseDto.md)
 - [ListMetricHistoryRequestDto](truefoundry/ml/_autogen/client/docs/ListMetricHistoryRequestDto.md)
 - [ListMetricHistoryResponseDto](truefoundry/ml/_autogen/client/docs/ListMetricHistoryResponseDto.md)
 - [ListModelVersionResponseDto](truefoundry/ml/_autogen/client/docs/ListModelVersionResponseDto.md)
 - [ListModelVersionsRequestDto](truefoundry/ml/_autogen/client/docs/ListModelVersionsRequestDto.md)
 - [ListModelsRequestDto](truefoundry/ml/_autogen/client/docs/ListModelsRequestDto.md)
 - [ListModelsResponseDto](truefoundry/ml/_autogen/client/docs/ListModelsResponseDto.md)
 - [ListRunArtifactsResponseDto](truefoundry/ml/_autogen/client/docs/ListRunArtifactsResponseDto.md)
 - [ListRunLogsResponseDto](truefoundry/ml/_autogen/client/docs/ListRunLogsResponseDto.md)
 - [LocalArtifactSource](truefoundry/ml/_autogen/client/docs/LocalArtifactSource.md)
 - [LocalModelSource](truefoundry/ml/_autogen/client/docs/LocalModelSource.md)
 - [LogBatchRequestDto](truefoundry/ml/_autogen/client/docs/LogBatchRequestDto.md)
 - [LogMetricRequestDto](truefoundry/ml/_autogen/client/docs/LogMetricRequestDto.md)
 - [LogParamRequestDto](truefoundry/ml/_autogen/client/docs/LogParamRequestDto.md)
 - [Manifest](truefoundry/ml/_autogen/client/docs/Manifest.md)
 - [Manifest1](truefoundry/ml/_autogen/client/docs/Manifest1.md)
 - [Manifest2](truefoundry/ml/_autogen/client/docs/Manifest2.md)
 - [Method](truefoundry/ml/_autogen/client/docs/Method.md)
 - [MetricCollectionDto](truefoundry/ml/_autogen/client/docs/MetricCollectionDto.md)
 - [MetricDto](truefoundry/ml/_autogen/client/docs/MetricDto.md)
 - [MimeType](truefoundry/ml/_autogen/client/docs/MimeType.md)
 - [ModelConfiguration](truefoundry/ml/_autogen/client/docs/ModelConfiguration.md)
 - [ModelDto](truefoundry/ml/_autogen/client/docs/ModelDto.md)
 - [ModelManifest](truefoundry/ml/_autogen/client/docs/ModelManifest.md)
 - [ModelResponseDto](truefoundry/ml/_autogen/client/docs/ModelResponseDto.md)
 - [ModelServer](truefoundry/ml/_autogen/client/docs/ModelServer.md)
 - [ModelVersionDto](truefoundry/ml/_autogen/client/docs/ModelVersionDto.md)
 - [ModelVersionEnvironment](truefoundry/ml/_autogen/client/docs/ModelVersionEnvironment.md)
 - [ModelVersionResponseDto](truefoundry/ml/_autogen/client/docs/ModelVersionResponseDto.md)
 - [MultiPartUploadDto](truefoundry/ml/_autogen/client/docs/MultiPartUploadDto.md)
 - [MultiPartUploadResponseDto](truefoundry/ml/_autogen/client/docs/MultiPartUploadResponseDto.md)
 - [MultiPartUploadStorageProvider](truefoundry/ml/_autogen/client/docs/MultiPartUploadStorageProvider.md)
 - [NotifyArtifactVersionFailureDto](truefoundry/ml/_autogen/client/docs/NotifyArtifactVersionFailureDto.md)
 - [ONNXFramework](truefoundry/ml/_autogen/client/docs/ONNXFramework.md)
 - [OpenapiSpec](truefoundry/ml/_autogen/client/docs/OpenapiSpec.md)
 - [PaddleFramework](truefoundry/ml/_autogen/client/docs/PaddleFramework.md)
 - [ParamDto](truefoundry/ml/_autogen/client/docs/ParamDto.md)
 - [Parameters](truefoundry/ml/_autogen/client/docs/Parameters.md)
 - [PyTorchFramework](truefoundry/ml/_autogen/client/docs/PyTorchFramework.md)
 - [ResolveAgentAppResponseDto](truefoundry/ml/_autogen/client/docs/ResolveAgentAppResponseDto.md)
 - [RestoreRunRequestDto](truefoundry/ml/_autogen/client/docs/RestoreRunRequestDto.md)
 - [RunDataDto](truefoundry/ml/_autogen/client/docs/RunDataDto.md)
 - [RunDto](truefoundry/ml/_autogen/client/docs/RunDto.md)
 - [RunInfoDto](truefoundry/ml/_autogen/client/docs/RunInfoDto.md)
 - [RunLogDto](truefoundry/ml/_autogen/client/docs/RunLogDto.md)
 - [RunLogInputDto](truefoundry/ml/_autogen/client/docs/RunLogInputDto.md)
 - [RunResponseDto](truefoundry/ml/_autogen/client/docs/RunResponseDto.md)
 - [RunTagDto](truefoundry/ml/_autogen/client/docs/RunTagDto.md)
 - [SearchRunsRequestDto](truefoundry/ml/_autogen/client/docs/SearchRunsRequestDto.md)
 - [SearchRunsResponseDto](truefoundry/ml/_autogen/client/docs/SearchRunsResponseDto.md)
 - [SetExperimentTagRequestDto](truefoundry/ml/_autogen/client/docs/SetExperimentTagRequestDto.md)
 - [SetTagRequestDto](truefoundry/ml/_autogen/client/docs/SetTagRequestDto.md)
 - [SignedURLDto](truefoundry/ml/_autogen/client/docs/SignedURLDto.md)
 - [SklearnFramework](truefoundry/ml/_autogen/client/docs/SklearnFramework.md)
 - [SklearnModelSchema](truefoundry/ml/_autogen/client/docs/SklearnModelSchema.md)
 - [SklearnSerializationFormat](truefoundry/ml/_autogen/client/docs/SklearnSerializationFormat.md)
 - [Source](truefoundry/ml/_autogen/client/docs/Source.md)
 - [Source1](truefoundry/ml/_autogen/client/docs/Source1.md)
 - [Source2](truefoundry/ml/_autogen/client/docs/Source2.md)
 - [SpaCyFramework](truefoundry/ml/_autogen/client/docs/SpaCyFramework.md)
 - [StatsModelsFramework](truefoundry/ml/_autogen/client/docs/StatsModelsFramework.md)
 - [Stop](truefoundry/ml/_autogen/client/docs/Stop.md)
 - [StoreRunLogsRequestDto](truefoundry/ml/_autogen/client/docs/StoreRunLogsRequestDto.md)
 - [Subject](truefoundry/ml/_autogen/client/docs/Subject.md)
 - [SubjectType](truefoundry/ml/_autogen/client/docs/SubjectType.md)
 - [SystemMessage](truefoundry/ml/_autogen/client/docs/SystemMessage.md)
 - [TensorFlowFramework](truefoundry/ml/_autogen/client/docs/TensorFlowFramework.md)
 - [Text](truefoundry/ml/_autogen/client/docs/Text.md)
 - [TextContentPart](truefoundry/ml/_autogen/client/docs/TextContentPart.md)
 - [TransformersFramework](truefoundry/ml/_autogen/client/docs/TransformersFramework.md)
 - [TriggerJobRunConfigRequestDto](truefoundry/ml/_autogen/client/docs/TriggerJobRunConfigRequestDto.md)
 - [TriggerJobRunConfigResponseDto](truefoundry/ml/_autogen/client/docs/TriggerJobRunConfigResponseDto.md)
 - [TrueFoundryManagedSource](truefoundry/ml/_autogen/client/docs/TrueFoundryManagedSource.md)
 - [UpdateArtifactVersionRequestDto](truefoundry/ml/_autogen/client/docs/UpdateArtifactVersionRequestDto.md)
 - [UpdateDatasetRequestDto](truefoundry/ml/_autogen/client/docs/UpdateDatasetRequestDto.md)
 - [UpdateExperimentRequestDto](truefoundry/ml/_autogen/client/docs/UpdateExperimentRequestDto.md)
 - [UpdateModelVersionRequestDto](truefoundry/ml/_autogen/client/docs/UpdateModelVersionRequestDto.md)
 - [UpdateRunRequestDto](truefoundry/ml/_autogen/client/docs/UpdateRunRequestDto.md)
 - [UpdateRunResponseDto](truefoundry/ml/_autogen/client/docs/UpdateRunResponseDto.md)
 - [Url](truefoundry/ml/_autogen/client/docs/Url.md)
 - [UserMessage](truefoundry/ml/_autogen/client/docs/UserMessage.md)
 - [ValidateExternalStorageRootRequestDto](truefoundry/ml/_autogen/client/docs/ValidateExternalStorageRootRequestDto.md)
 - [ValidateExternalStorageRootResponseDto](truefoundry/ml/_autogen/client/docs/ValidateExternalStorageRootResponseDto.md)
 - [ValidationError](truefoundry/ml/_autogen/client/docs/ValidationError.md)
 - [ValidationErrorLocInner](truefoundry/ml/_autogen/client/docs/ValidationErrorLocInner.md)
 - [XGBoostFramework](truefoundry/ml/_autogen/client/docs/XGBoostFramework.md)
 - [XGBoostModelSchema](truefoundry/ml/_autogen/client/docs/XGBoostModelSchema.md)
 - [XGBoostSerializationFormat](truefoundry/ml/_autogen/client/docs/XGBoostSerializationFormat.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKey"></a>
### APIKey

- **Type**: Bearer authentication


## Author
